<?xml version="1.0" encoding="UTF-8"?>
<!--
	This template converts data in e-DWR Schema format to the SDWIS/State EDI
	format.
	
	Written by Maggie Hsueh, enfoTech  & Consulting Inc., 2004-10-13
-->
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:EN="urn:us:net:exchangenetwork" xmlns:facid="http://www.epa.gov/xml" xmlns:js="javascript:code">
	<xsl:output method="text" version="1.0" encoding="UTF-8" indent="yes"/>
	<!-- global variables -->
	<xsl:variable name="HeaderRecordName" select="'HDR'"/>
	<xsl:variable name="DetailRecordName" select="'DTR'"/>
	<xsl:variable name="ReportType" select="'T'"/>
	<xsl:variable name="CarriageReturn" select="'&#xD;'"/>
	<xsl:variable name="Linefeed" select="'&#xA;'"/>
	<xsl:variable name="Space" select="'&#x20;'"/>
	<!-- skip these nodes when processing XSLT -->
	<xsl:template match="EN:MetaData"/>
	<xsl:template match="EN:Receiver"/>
	<xsl:template match="EN:Sender"/>
	<xsl:template match="EN:ReportIdentification"/>
	<xsl:template match="EN:LabIdentification"/>
	<xsl:template match="EN:ReportCertification"/>
	<xsl:template match="EN:SubmissionCertification"/>
	<!-- The EN:Sample template does most of the work in this stylesheet -->
	<xsl:template match="EN:Sample">
		<!-- *************** SAMPLE SUMMARY *************** -->
		<!-- 1	3	1 - 3			B_RECORD_NAME  -->
		<xsl:value-of select="$HeaderRecordName"/>
		<!-- 2	1	4				B_REPORT_TYPE -->
		<xsl:value-of select="$ReportType"/>
		<!-- 3	10	5 - 14 			B_TRANSACTION_NUMBER (not in use) -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="''"/>
			<xsl:with-param name="length" select="10"/>
		</xsl:call-template>
		<!-- 4	20	15 - 34			B_LAB_SAMPLE_NUMBER -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:LabSampleIdentifier"/>
			<xsl:with-param name="length" select="20"/>
		</xsl:call-template>
		<!-- 5	20	35 - 54			B_STATE_SAMPLE_NUMBER -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:StateSampleIdentifier"/>
			<xsl:with-param name="length" select="20"/>
		</xsl:call-template>
		<!-- 6	11	55 - 65			B_WATER_SYSTEM_NUMBER -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:PWSIdentifier"/>
			<xsl:with-param name="length" select="11"/>
		</xsl:call-template>
		<!-- 6.A	1	66				B_REPLACEMENT_INDICATOR -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:AdditionalSampleIndicator"/>
			<xsl:with-param name="length" select="1"/>
		</xsl:call-template>
		<!-- 7	10	67 - 76			B_STATE_LABORATORY_NUMBER -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="ancestor::EN:LabReport/EN:LabIdentification/EN:LabStateIdentifier"/>
			<xsl:with-param name="length" select="10"/>
		</xsl:call-template>
		<!-- 8	10	77 - 86			B_FEDERAL_LABORATORY_NUMBER -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="ancestor::EN:LabReport/EN:LabIdentification/EN:LabFederalIdentifier"/>
			<xsl:with-param name="length" select="10"/>
		</xsl:call-template>
		<!-- 9	12	87 - 98			B_WATER_FACILITY_STATE_CODE -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:PWSFacilityIdentifier"/>
			<xsl:with-param name="length" select="12"/>
		</xsl:call-template>
		<!-- 10	11	99 - 109		B_SAMPLING_POINT -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleLocationIdentification/EN:SampleLocationIdentifier"/>
			<xsl:with-param name="length" select="11"/>
		</xsl:call-template>
		<!-- 11	20	110 - 129		B_SAMPLING_LOCATION -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleLocationIdentification/EN:SampleLocationName"/>
			<xsl:with-param name="length" select="20"/>
		</xsl:call-template>
		<!-- 12	2	130 - 131		B_SAMPLE_CATEGORY -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:SampleRuleCode"/>
			<xsl:with-param name="length" select="2"/>
		</xsl:call-template>
		<!-- 13	1	132				B_COMPLIANCE_INDICATOR -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:ComplianceSampleIndicator"/>
			<xsl:with-param name="length" select="1"/>
		</xsl:call-template>
		<!-- 14	8	133 - 140		B_COLLECTION_DATE -->
		<xsl:call-template name="format-date">
			<xsl:with-param name="datevalue" select="EN:SampleIdentification/EN:SampleCollectionStartDate"/>
		</xsl:call-template>
		<!-- 15	6	141 - 146		B_COLLECTION_TIME -->
		<xsl:call-template name="format-time">
			<xsl:with-param name="timevalue" select="EN:SampleIdentification/EN:SampleCollectionStartTime"/>
		</xsl:call-template>
		<!-- 16	2	147 - 148		B_SAMPLE_TYPE -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:SampleMonitoringTypeCode"/>
			<xsl:with-param name="length" select="2"/>
		</xsl:call-template>
		<!-- 17	2	149 - 150		B_REPEAT_LOCATION_CODE -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleLocationIdentification/EN:SampleRepeateLocationCode"/>
			<xsl:with-param name="length" select="2"/>
		</xsl:call-template>
		<!--18	8	151 - 158		B_LAB_RECEIPT_DATE_SAMPLE -->
		<xsl:call-template name="format-date">
			<xsl:with-param name="datevalue" select="EN:SampleIdentification/EN:SampleLaboratoryReceiptDate"/>
		</xsl:call-template>
		<!-- 19	5	159 - 163		B_COLLECTOR_IDENTIFICATION_NUMBER (not in use) -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="''"/>
			<xsl:with-param name="length" select="5"/>
		</xsl:call-template>
		<!-- 20	40	164 - 203 		B_COLLECTOR_NAME -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:SampleCollector/facid:IndividualFullName"/>
			<xsl:with-param name="length" select="40"/>
		</xsl:call-template>
		<!-- 21	9	204 - 212		B_SAMPLE_VOLUME -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:SampleVolume/EN:MeasurementValue"/>
			<xsl:with-param name="length" select="9"/>
		</xsl:call-template>
		<!-- 22	3	213 - 215		B_LEAD_COPPER_SAMPLE_TYPE -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:SampleCollectionTypeCode"/>
			<xsl:with-param name="length" select="3"/>
		</xsl:call-template>
		<!-- 23	2	216 - 217		B_SAMPLE_REJECTION_REASON -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:SampleRejectionReasonCode"/>
			<xsl:with-param name="length" select="2"/>
		</xsl:call-template>
		<!-- 24	12	218 - 229		B_COLLECTION_METHOD_CODE -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:SampleCollectionMethod/EN:MethodIdentifier"/>
			<xsl:with-param name="length" select="12"/>
		</xsl:call-template>
		<!-- 25	20	230 - 249		B_ORIGINAL_LAB_SAMPLE_NUMBER -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:OriginalSampleIdentifier"/>
			<xsl:with-param name="length" select="20"/>
		</xsl:call-template>
		<!-- 26	20	250 - 269		B_LAB_COMPOSITE_NUMBER -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:LabSampleCompositeNumber"/>
			<xsl:with-param name="length" select="20"/>
		</xsl:call-template>
		<!-- 27	8	270 - 277		B_COMPOSITE_DATE -->
		<xsl:call-template name="format-date">
			<xsl:with-param name="datevalue" select="EN:SampleIdentification/EN:LabSampleCompositeDate"/>
		</xsl:call-template>
		<!-- 28	1	278				B_COMPOSITE_INDICATOR -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="''"/>
			<xsl:with-param name="length" select="1"/>
		</xsl:call-template>
		<!-- 29	1	279				B_COMPOSITE_QUARTER -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="''"/>
			<xsl:with-param name="length" select="1"/>
		</xsl:call-template>
		<!-- 30	4	280 - 283		B_ANALYTE_CODE (not in use) -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="''"/>
			<xsl:with-param name="length" select="4"/>
		</xsl:call-template>
		<!-- 31	10	284 - 293		B_CAS_NUMBER (not in use) -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="''"/>
			<xsl:with-param name="length" select="10"/>
		</xsl:call-template>
		<!-- 32	8	294 - 301		B_MONITORING_PERIOD_START_DATE (not in use) -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="''"/>
			<xsl:with-param name="length" select="8"/>
		</xsl:call-template>
		<!-- 33	8	302 - 309		B_MONITORING_PERIOD_END_DATE (not in use) -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="''"/>
			<xsl:with-param name="length" select="8"/>
		</xsl:call-template>
		<!-- 34	12	310 - 321		B_ANALYSIS_METHOD_CODE (not in use) -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="''"/>
			<xsl:with-param name="length" select="12"/>
		</xsl:call-template>
		<!-- 35	5 (4(2))	322 - 326	B_FREE_CHLORINE_RESIDUAL -->
		<xsl:choose>
			<xsl:when test="EN:SampleIdentification/EN:SpecializedMeasurement/EN:SpecializedMeasurementTypeCode = 'Free Chlorine Residual'">
				<xsl:call-template name="format-number">
					<xsl:with-param name="numberValue" select="EN:SampleIdentification/EN:SpecializedMeasurement/EN:MeasurementValue"/>
					<xsl:with-param name="numberFormat" select="'#0.00'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="append-pad">
					<xsl:with-param name="padChar" select="' '"/>
					<xsl:with-param name="padVar" select="''"/>
					<xsl:with-param name="length" select="5"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<!-- 36	5 (4(2))	327 - 331	B_TOTL_CHLORINE_RESIDUAL -->
		<xsl:choose>
			<xsl:when test="EN:SampleIdentification/EN:SpecializedMeasurement/EN:SpecializedMeasurementTypeCode = 'Total Chlorine Residual'">
				<xsl:call-template name="format-number">
					<xsl:with-param name="numberValue" select="EN:SampleIdentification/EN:SpecializedMeasurement/EN:MeasurementValue"/>
					<xsl:with-param name="numberFormat" select="'#0.00'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="append-pad">
					<xsl:with-param name="padChar" select="' '"/>
					<xsl:with-param name="padVar" select="''"/>
					<xsl:with-param name="length" select="5"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<!-- 37	4 (3(1))	332 - 335	B_SAMPLE_WATER_TEMPERATURE -->
		<xsl:choose>
			<xsl:when test="EN:SampleIdentification/EN:SpecializedMeasurement/EN:SpecializedMeasurementTypeCode = 'Sample Water Temperature'">
				<xsl:call-template name="format-number">
					<xsl:with-param name="numberValue" select="EN:SampleIdentification/EN:SpecializedMeasurement/EN:MeasurementValue"/>
					<xsl:with-param name="numberFormat" select="'#0.0'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="append-pad">
					<xsl:with-param name="padChar" select="' '"/>
					<xsl:with-param name="padVar" select="''"/>
					<xsl:with-param name="length" select="4"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<!-- 38	1	336				B_TEMPERATURE_UNIT_MEASURE -->
		<xsl:choose>
			<xsl:when test="EN:SampleIdentification/EN:SpecializedMeasurement/EN:SpecializedMeasurementTypeCode = 'Sample Water Temperature'">
				<xsl:call-template name="append-pad">
					<xsl:with-param name="padChar" select="' '"/>
					<xsl:with-param name="padVar" select="EN:SampleIdentification/EN:SpecializedMeasurement/EN:MeasurementUnit"/>
					<xsl:with-param name="length" select="1"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="append-pad">
					<xsl:with-param name="padChar" select="' '"/>
					<xsl:with-param name="padVar" select="''"/>
					<xsl:with-param name="length" select="1"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<!-- 39	6 (5(2))	337 - 342	B_TURBIDITY_MEASURE -->
		<xsl:choose>
			<xsl:when test="EN:SampleIdentification/EN:SpecializedMeasurement/EN:SpecializedMeasurementTypeCode = 'Turbidity Measure'">
				<xsl:call-template name="format-number">
					<xsl:with-param name="numberValue" select="EN:SampleIdentification/EN:SpecializedMeasurement/EN:MeasurementValue"/>
					<xsl:with-param name="numberFormat" select="'##0.00'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="append-pad">
					<xsl:with-param name="padChar" select="' '"/>
					<xsl:with-param name="padVar" select="''"/>
					<xsl:with-param name="length" select="6"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<!-- 40	5 (4(1))	343 - 347	B_PH_MEASURE -->
		<xsl:choose>
			<xsl:when test="EN:SampleIdentification/EN:SpecializedMeasurement/EN:SpecializedMeasurementTypeCode = 'PH Measure'">
				<xsl:call-template name="format-number">
					<xsl:with-param name="numberValue" select="EN:SampleIdentification/EN:SpecializedMeasurement/EN:MeasurementValue"/>
					<xsl:with-param name="numberFormat" select="'##0.0'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="append-pad">
					<xsl:with-param name="padChar" select="' '"/>
					<xsl:with-param name="padVar" select="''"/>
					<xsl:with-param name="length" select="5"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<!-- 41	8 (7(4))	348 - 355	B_FLOW_RATE -->
		<xsl:choose>
			<xsl:when test="EN:SampleIdentification/EN:SpecializedMeasurement/EN:SpecializedMeasurementTypeCode = 'Flow Rate'">
				<xsl:call-template name="format-number">
					<xsl:with-param name="numberValue" select="EN:SampleIdentification/EN:SpecializedMeasurement/EN:MeasurementValue"/>
					<xsl:with-param name="numberFormat" select="'##0.0000'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="append-pad">
					<xsl:with-param name="padChar" select="' '"/>
					<xsl:with-param name="padVar" select="''"/>
					<xsl:with-param name="length" select="8"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<!-- filler (size:20) -->
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="''"/>
			<xsl:with-param name="length" select="20"/>
		</xsl:call-template>
		<!-- new line -->
		<xsl:value-of select="$CarriageReturn"/>
		<xsl:value-of select="$Linefeed"/>
		<!-- *************** SAMPLE RESULT *************** -->
		<xsl:for-each select="EN:AnalysisResultInformation">
			<!-- 1	3	1 - 3			B_RECORD_NAME -->
			<xsl:value-of select="$DetailRecordName"/>
			<!-- 2	1	4				B_REPORT_TYPE -->
			<xsl:value-of select="$ReportType"/>
			<!-- 3	10	5 - 14			B_TRANSACTION_NUMBER (not in use)	-->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="''"/>
				<xsl:with-param name="length" select="10"/>
			</xsl:call-template>
			<!-- 4	20	15 - 34			B_LAB_SAMPLE_NUMBER -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="ancestor::EN:Sample/EN:SampleIdentification/EN:LabSampleIdentifier"/>
				<xsl:with-param name="length" select="20"/>
			</xsl:call-template>
			<!-- 5	12	35 - 46			B_WATER_SYSTEM_NUMBER -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="ancestor::EN:Sample/EN:SampleIdentification/EN:PWSIdentifier"/>
				<xsl:with-param name="length" select="12"/>
			</xsl:call-template>
			<!-- 6	4	47 - 50			B_ANALYTE_CODE -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="EN:AnalyteIdentification/EN:AnalyteCode"/>
				<xsl:with-param name="length" select="4"/>
			</xsl:call-template>
			<!-- 7	10	51 - 60			B_CAS_NUMBER -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="EN:AnalyteIdentification/EN:CASRegistryNumber"/>
				<xsl:with-param name="length" select="10"/>
			</xsl:call-template>
			<!-- 8	8	61 - 68			B_ANALYSIS_START_DATE -->
			<xsl:call-template name="format-date">
				<xsl:with-param name="datevalue" select="EN:LabAnalysisIdentification/EN:AnalysisStartDate"/>
			</xsl:call-template>
			<!-- 9	6	69 - 74			B_ANALYSIS_START_TIME -->
			<xsl:call-template name="format-time">
				<xsl:with-param name="timevalue" select="EN:LabAnalysisIdentification/EN:AnalysisStartTime"/>
			</xsl:call-template>
			<!-- 10	8	75 - 82			B_ANALYSIS_COMPLETION_DATE -->
			<xsl:call-template name="format-date">
				<xsl:with-param name="datevalue" select="EN:LabAnalysisIdentification/EN:AnalysisEndDate"/>
			</xsl:call-template>
			<!-- 11	6	83 - 88			B_ANALYSIS_COMPLETION_TIME -->
			<xsl:call-template name="format-time">
				<xsl:with-param name="timevalue" select="EN:LabAnalysisIdentification/EN:AnalysisEndTime"/>
			</xsl:call-template>
			<!-- 12	8	89 - 96			B_STATE_NOTIFY_DATE -->
			<xsl:call-template name="format-date">
				<xsl:with-param name="datevalue" select="EN:AnalysisResult/EN:ResultStateNotificationDate"/>
			</xsl:call-template>
			<!-- 13	1	97				B_DATA_QUALITY -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="EN:QAQCSummary/EN:DataQualityCode"/>
				<xsl:with-param name="length" select="1"/>
			</xsl:call-template>
			<!-- 14	2	98 - 99			B_DATA_QUALITY_REASON -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="EN:QAQCSummary/EN:DataQualityRejectCode"/>
				<xsl:with-param name="length" select="2"/>
			</xsl:call-template>
			<!-- 15	12	100 - 111		B_ANALYSIS_METHOD_CODE -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="EN:LabAnalysisIdentification/EN:SampleAnalyticalMethod/EN:MethodIdentifier"/>
				<xsl:with-param name="length" select="12"/>
			</xsl:call-template>
			<!-- 16	8	112 - 119		B_MONITORING_PERIOD_START_DATE -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="''"/>
				<xsl:with-param name="length" select="8"/>
			</xsl:call-template>
			<!-- 17	8	120 - 127		B_MONITORING_PERIOD_END_DATE -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="''"/>
				<xsl:with-param name="length" select="8"/>
			</xsl:call-template>
			<!-- 18	9	128 - 136		B_VOLUME_ASSAYED -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="EN:LabAnalysisIdentification/EN:SampleAnalyzedMeasure/EN:MeasurementValue"/>
				<xsl:with-param name="length" select="9"/>
			</xsl:call-template>
			<!-- 19	4	137 - 140		B_LAB_REJECTION_REASON -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="EN:AnalysisResult/EN:SampleInterferenceReasonCode"/>
				<xsl:with-param name="length" select="4"/>
			</xsl:call-template>
			<xsl:variable name="SampleRuleCode" select="ancestor::EN:Sample/EN:SampleIdentification/EN:SampleRuleCode"/>
			<!-- 20	1	141				B_MICROBE_PRESENCE_INDICATOR -->
			<xsl:choose>
				<xsl:when test="($SampleRuleCode = 'MB') or ($SampleRuleCode  = 'TC')">
					<xsl:call-template name="append-pad">
						<xsl:with-param name="padChar" select="' '"/>
						<xsl:with-param name="padVar" select="EN:AnalysisResult/EN:Result/EN:MeasurementQualifier"/>
						<xsl:with-param name="length" select="1"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="append-pad">
						<xsl:with-param name="padChar" select="' '"/>
						<xsl:with-param name="padVar" select="''"/>
						<xsl:with-param name="length" select="1"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!-- 21	1	142				B_TEST_TYPE (not mapped) -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="''"/>
				<xsl:with-param name="length" select="1"/>
			</xsl:call-template>
			<!-- 22	10	143 - 152		B_COUNT -->
			<xsl:choose>
				<xsl:when test="($SampleRuleCode= 'MB') or ($SampleRuleCode  = 'TC')">
					<xsl:call-template name="append-pad">
						<xsl:with-param name="padChar" select="' '"/>
						<xsl:with-param name="padVar" select="EN:AnalysisResult/EN:Result/EN:MeasurementValue"/>
						<xsl:with-param name="length" select="10"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="append-pad">
						<xsl:with-param name="padChar" select="' '"/>
						<xsl:with-param name="padVar" select="''"/>
						<xsl:with-param name="length" select="10"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!-- 23	10	153 - 162		B_COUNT_TYPE -->
			<xsl:choose>
				<xsl:when test="($SampleRuleCode= 'MB') or ($SampleRuleCode  = 'TC')">
					<xsl:call-template name="append-pad">
						<xsl:with-param name="padChar" select="' '"/>
						<xsl:with-param name="padVar" select="EN:AnalysisResult/EN:Result/EN:MicrobialResultCountTypeCode"/>
						<xsl:with-param name="length" select="10"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="append-pad">
						<xsl:with-param name="padChar" select="' '"/>
						<xsl:with-param name="padVar" select="''"/>
						<xsl:with-param name="length" select="10"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!-- 24	9	163 - 171		B_COUNT_UNITS -->
			<xsl:choose>
				<xsl:when test="($SampleRuleCode = 'MB') or ($SampleRuleCode  = 'TC')">
					<xsl:call-template name="append-pad">
						<xsl:with-param name="padChar" select="' '"/>
						<xsl:with-param name="padVar" select="EN:AnalysisResult/EN:Result/EN:MeasurementUnit"/>
						<xsl:with-param name="length" select="9"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="append-pad">
						<xsl:with-param name="padChar" select="' '"/>
						<xsl:with-param name="padVar" select="''"/>
						<xsl:with-param name="length" select="9"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!-- 25	1	172				B_LESS_THAN_INDICATOR -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="EN:AnalysisResult/EN:DetectionLevelIndicator"/>
				<xsl:with-param name="length" select="1"/>
			</xsl:call-template>
			<!-- 26	3	173 - 175		B_LESS_THAN_CODE -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="EN:AnalysisResult/EN:DetectionLimitTypeCode"/>
				<xsl:with-param name="length" select="3"/>
			</xsl:call-template>
			<!-- 27	16 (15(8))	176 - 191	B_DETECTION_LEVEL -->
			<xsl:call-template name="format-number">
				<xsl:with-param name="numberValue" select="EN:AnalysisResult/EN:DetectionLimit/EN:MeasurementValue"/>
				<xsl:with-param name="numberFormat" select="'######0.00000000'"/>
			</xsl:call-template>
			<!-- 28	9	192 - 200 			B_DETECTION_LEVEL_UNIT_CODE -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="EN:AnalysisResult/EN:DetectionLimit/EN:MeasurementUnit"/>
				<xsl:with-param name="length" select="9"/>
			</xsl:call-template>
			<!-- 29	14 (13(9))	201 - 214	B_CONCENTRATION -->
			<xsl:choose>
				<xsl:when test="($SampleRuleCode != 'MB') and ($SampleRuleCode  != 'TC')">
					<xsl:call-template name="format-number">
						<xsl:with-param name="numberValue" select="EN:AnalysisResult/EN:Result/EN:MeasurementValue"/>
						<xsl:with-param name="numberFormat" select="'###0.000000000'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="append-pad">
						<xsl:with-param name="padChar" select="' '"/>
						<xsl:with-param name="padVar" select="''"/>
						<xsl:with-param name="length" select="14"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!-- 30	9	215 - 223		B_CONCENTRATION_UNIT_CODE -->
			<xsl:choose>
				<xsl:when test="($SampleRuleCode != 'MB') and ($SampleRuleCode  != 'TC')">
					<xsl:call-template name="append-pad">
						<xsl:with-param name="padChar" select="' '"/>
						<xsl:with-param name="padVar" select="EN:AnalysisResult/EN:Result/EN:MeasurementUnit"/>
						<xsl:with-param name="length" select="9"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="append-pad">
						<xsl:with-param name="padChar" select="' '"/>
						<xsl:with-param name="padVar" select="''"/>
						<xsl:with-param name="length" select="9"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!-- 31	10	224 - 233		B_REPORTED_MEASURE -->
			<xsl:choose>
				<xsl:when test="($SampleRuleCode != 'MB') and ($SampleRuleCode  != 'TC')">
					<xsl:call-template name="append-pad">
						<xsl:with-param name="padChar" select="' '"/>
						<xsl:with-param name="padVar" select="EN:AnalysisResult/EN:Result/EN:MeasurementValue"/>
						<xsl:with-param name="length" select="10"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="append-pad">
						<xsl:with-param name="padChar" select="' '"/>
						<xsl:with-param name="padVar" select="''"/>
						<xsl:with-param name="length" select="10"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!-- 32	9 (8(3))	234 - 242	B_REPORTED_MEASURE_COUNT_ERROR -->
			<xsl:call-template name="format-number">
				<xsl:with-param name="numberValue" select="EN:AnalysisResult/EN:RadiologicalResultCountError"/>
				<xsl:with-param name="numberFormat" select="'####0.000'"/>
			</xsl:call-template>
			<!-- 33	2	243 - 244		B_RESULTS_TYPE -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="''"/>
				<xsl:with-param name="length" select="2"/>
			</xsl:call-template>
			<!-- 34	10	245 - 254		B_COUNT_QUANTITY -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="''"/>
				<xsl:with-param name="length" select="10"/>
			</xsl:call-template>
			<!-- 35	14(13(9))	255 - 268	B_MEASURE -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="''"/>
				<xsl:with-param name="length" select="14"/>
			</xsl:call-template>
			<!-- 36	9	269 - 277		B_MEASURE_UNIT_CODE -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="''"/>
				<xsl:with-param name="length" select="9"/>
			</xsl:call-template>
			<!-- 	filler 98	278 - 375 -->
			<xsl:call-template name="append-pad">
				<xsl:with-param name="padChar" select="' '"/>
				<xsl:with-param name="padVar" select="' '"/>
				<xsl:with-param name="length" select="98"/>
			</xsl:call-template>
			<!-- new line -->
			<xsl:value-of select="$CarriageReturn"/>
			<xsl:value-of select="$Linefeed"/>
		</xsl:for-each>
	</xsl:template>
	<!-- Template:append-pad -->
	<!-- recursive template to left justify and append, the value with whatever padChar is passed in  -->
	<xsl:template name="append-pad">
		<xsl:param name="padChar"/>
		<xsl:param name="padVar"/>
		<xsl:param name="length"/>
		<xsl:choose>
			<xsl:when test="string-length($padVar) &lt; $length">
				<xsl:call-template name="append-pad">
					<xsl:with-param name="padChar" select="$padChar"/>
					<xsl:with-param name="padVar" select="concat($padVar,$padChar)"/>
					<xsl:with-param name="length" select="$length"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="substring($padVar,1,$length)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Template: format-edi-number -->
	<xsl:template name="format-number">
		<xsl:param name="numberValue"/>
		<xsl:param name="numberFormat"/>
		<xsl:choose>
			<xsl:when test="string($numberValue) = ''">
				<xsl:value-of select="translate($numberFormat, '0#.', '   ')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="string(number($numberValue)) = 'NaN'">
						<xsl:value-of select="translate($numberFormat, '0', '#')"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="maxNumber" select="translate($numberFormat, '#0', '99')"/>
						<xsl:choose>
							<xsl:when test="$numberValue&gt; $maxNumber">
								<xsl:value-of select="translate($numberFormat, '0', '#')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:variable name="formattedNumber" select="format-number($numberValue, $numberFormat)"/>
								<xsl:call-template name="append-pad">
									<xsl:with-param name="padChar" select="' '"/>
									<xsl:with-param name="padVar" select="$formattedNumber"/>
									<xsl:with-param name="length" select="string-length($numberFormat)"/>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Template: format-date -->
	<xsl:template name="format-date">
		<xsl:param name="datevalue"/>
		<xsl:choose>
			<xsl:when test="string-length($datevalue) = 10">
				<xsl:value-of select="concat(substring(translate($datevalue, '-', ''),5),substring(translate($datevalue, '-', ''),1, 4))"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="append-pad">
					<xsl:with-param name="padChar" select="' '"/>
					<xsl:with-param name="padVar" select="$datevalue"/>
					<xsl:with-param name="length" select="8"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Template: format-time -->
	<xsl:template name="format-time">
		<xsl:param name="timevalue"/>
		<xsl:call-template name="append-pad">
			<xsl:with-param name="padChar" select="' '"/>
			<xsl:with-param name="padVar" select="translate($timevalue, ':', '')"/>
			<xsl:with-param name="length" select="6"/>
		</xsl:call-template>
	</xsl:template>
</xsl:stylesheet>
